<?
######## Confixx(R) 3.2.1 Professional ############
####### Copyright SWsoft, Inc. 2004-2006 ##########
##### http://www.swsoft.com - info@swsoft.com #####


$lang_version = '3.1.0';
$lang_short = 'de';
$lang_name_int = 'German';
$lang_name_nat = 'Deutsch';

$lang_html_charset = 'ISO-8859-1';

$lang_format_date = 'n/j/Y';
$lang_format_datetime_short = 'd/m - H:i';
$lang_format_datetime_long = 'm/d/y - H:i:s';
$lang_format_time = 'H:i:s';

$lang_format_sep_dec = '.';
$lang_format_sep_kilo = ',';
$lang_format_kb_expr = 'KB';
$lang_format_mb_expr = 'MB';
$lang_format_gb_expr = 'GB';

$lang_text['advanced_mode'] = 'Erweiterter Modus';
$lang_text['al_drweb'] = 'DrWeb';
$lang_text['al_webshop'] = 'WebShop';
$lang_text['anne_cell_durationitem0'] = 'Tag(e)';
$lang_text['anne_cell_durationitem1'] = 'Woche(n)';
$lang_text['anne_cell_durationitem2'] = 'Monat(e)';
$lang_text['anne_cell_durationitem3'] = 'Jahr(e)';
$lang_text['confixx_easy'] = 'Confixx Easy';
$lang_text['confixx_page'] = 'Hier entstehen die Internet-Seiten des Confixx Benutzers';
$lang_text['current_path'] = 'Aktueller Pfad';
$lang_text['errtype_any'] = 'Alle:';
$lang_text['errtype_error'] = 'Fehler:';
$lang_text['errtype_errors'] = 'Fehler:';
$lang_text['errtype_notice'] = 'Hinweis:';
$lang_text['errtype_notices'] = 'Hinweise:';
$lang_text['errtype_warning'] = 'Warnung:';
$lang_text['errtype_warnings'] = 'Warnungen:';
$lang_text['form_all_required_fields'] = 'Alle Felder sind erforderlich.';
$lang_text['form_bad_ip'] = 'Ungltige IP-Adresse';
$lang_text['form_bad_logindata'] = 'Kann keinen Benutzer mit dem Benutzernamen und Passwort identifizieren. Versuchen Sie es mit den erweiterten Einstellungen';
$lang_text['form_bad_username'] = 'Ungltiger Benutzername und Passwort';
$lang_text['form_cancel'] = 'Abbrechen';
$lang_text['form_email'] = 'Email Adresse';
$lang_text['form_empty_required_fields'] = 'Required fields should be not empty.';
$lang_text['form_expand'] = 'Erweiterte Optionen anzeigen';
$lang_text['form_get_password'] = 'Passwort holen';
$lang_text['form_login'] = 'Einloggen';
$lang_text['form_logintext'] = 'Geben Sie Ihren Login und Ihr Passwort ein und klicken Sie dann auf "Einloggen".';
$lang_text['form_password'] = 'Passwort:';
$lang_text['form_please_login'] = 'Einloggen ins Parallels Confixx';
$lang_text['form_sent_pwd'] = 'Passwort via E-Mail verschicken.';
$lang_text['form_unexpand'] = 'Erweiterte Optionen verbergen';
$lang_text['form_username'] = 'Login:';
$lang_text['fp_incorrect_field'] = 'Feld <b>$VAR[0]</b> wurde inkorrekt ausgefllt. Bitte versuchen Sie es erneut.';
$lang_text['fp_incorrect_fields'] = 'Einige Felder wurden inkorrekt ausgefllt. Bitte versuchen Sie es erneut.';
$lang_text['fp_required_fields'] = 'erforderliche Felder.';
$lang_text['go_to_confixx'] = 'Zur Confixx-Homepage';
$lang_text['go_to_swsoft'] = 'Zur Parallels-Homepage';
$lang_text['help_frame__header'] = 'Hilfe';
$lang_text['help_frame__hide'] = 'Hilfe ausblenden';
$lang_text['help_frame__show'] = 'Hilfe einblenden';
$lang_text['httpd_option'] = 'Httpd Option';
$lang_text['httpd_option_label'] = 'Name';
$lang_text['httpd_option_state'] = 'Wert';
$lang_text['httpd_option_state_data'] = 'Httpd-Eintrag';
$lang_text['httpd_option_state_label'] = 'Wert';
$lang_text['httpd_option_state_off'] = 'Zustand "Aus"';
$lang_text['httpd_option_state_on'] = 'Zustand "Ein"';
$lang_text['httpd_options'] = 'Httpd Optionen';
$lang_text['httpd_options_new'] = 'Neue httpd Option';
$lang_text['httpd_options_not_set'] = 'Standardmig';
$lang_text['lang_months_1'] = 'Januar';
$lang_text['lang_months_10'] = 'Oktober';
$lang_text['lang_months_11'] = 'November';
$lang_text['lang_months_12'] = 'Dezember';
$lang_text['lang_months_2'] = 'Februar';
$lang_text['lang_months_3'] = 'Mrz';
$lang_text['lang_months_4'] = 'April';
$lang_text['lang_months_5'] = 'Mai';
$lang_text['lang_months_6'] = 'Juni';
$lang_text['lang_months_7'] = 'Juli';
$lang_text['lang_months_8'] = 'August';
$lang_text['lang_months_9'] = 'September';
$lang_text['ldf_activated'] = 'Aktiviert';
$lang_text['ldf_deactivated'] = 'Deaktiviert';
$lang_text['ldf_hardlimit'] = 'Hard-Limit';
$lang_text['ldf_limit_atdomains'] = 'At-Domains';
$lang_text['ldf_limit_auto'] = 'Anzahl E-Mail-Responder';
$lang_text['ldf_limit_cron'] = 'Cronjobs';
$lang_text['ldf_limit_domains'] = 'Anzahl Domains';
$lang_text['ldf_limit_email'] = 'Anzahl E-Mail-Adressen';
$lang_text['ldf_limit_ftp'] = 'Anzahl FTP-Benutzer';
$lang_text['ldf_limit_maillist'] = 'Mailinglisten';
$lang_text['ldf_limit_mailspace'] = 'Mail-Speicherplatz';
$lang_text['ldf_limit_mailspace_assigned'] = 'Vergebener Mail-Speicherplatz';
$lang_text['ldf_limit_mailspace_used'] = 'Verwendeter Mail-Speicherplatz';
$lang_text['ldf_limit_mysql'] = 'MySQL-Datenbanken';
$lang_text['ldf_limit_pop3'] = 'Anzahl POP3-Mailboxen';
$lang_text['ldf_limit_shareddomains'] = 'Shared-Domains';
$lang_text['ldf_limit_storage'] = 'Speicherplatz';
$lang_text['ldf_limit_storage_assigned'] = 'Zugewiesener Speicherplatz';
$lang_text['ldf_limit_storage_db'] = 'Von Datenbanken verwendeter Speicherplatz';
$lang_text['ldf_limit_storage_files'] = 'Von Dateien verwendeter Speicherplatz';
$lang_text['ldf_limit_storage_used'] = 'Verwendeter Speicherplatz';
$lang_text['ldf_limit_subdomains'] = 'Erstellbare Subdomains';
$lang_text['ldf_limit_traffic'] = 'Traffic';
$lang_text['ldf_limit_traffic_email'] = 'Verwendeter E-Mail-Traffic';
$lang_text['ldf_limit_traffic_ftp'] = 'Verwendeter FTP-Traffic';
$lang_text['ldf_limit_traffic_used'] = 'Verwendeter Traffic';
$lang_text['ldf_limit_traffic_web'] = 'Verwendeter Web-Traffic';
$lang_text['ldf_limit_users'] = 'Anzahl Benutzer';
$lang_text['ldf_limit_webapp'] = 'Webapplikationen';
$lang_text['ldf_limit_wildcard'] = 'Wildcard-Subdomains';
$lang_text['ldf_limits_title'] = 'Begrenzungen';
$lang_text['ldf_maximum'] = 'maximal';
$lang_text['ldf_services_title'] = 'Dienste';
$lang_text['ldf_unlimited'] = 'unbegrenzt';
$lang_text['ll_activate'] = 'Aktivieren';
$lang_text['ll_add'] = 'Hinzufgen';
$lang_text['ll_all'] = 'Alle';
$lang_text['ll_any'] = 'Beliebig';
$lang_text['ll_apply'] = 'Ausfhren';
$lang_text['ll_back'] = 'Zurck';
$lang_text['ll_cancel'] = 'Abbrechen';
$lang_text['ll_change'] = 'ndern';
$lang_text['ll_confirm'] = 'Besttigen';
$lang_text['ll_confirm_delete'] = 'Wollen Sie wirklich %d Elemente lschen';
$lang_text['ll_deactivate'] = 'Deaktivieren';
$lang_text['ll_delete'] = 'Lschen';
$lang_text['ll_delquest'] = 'Ausgewhlte Lschen?';
$lang_text['ll_edit'] = 'Editieren';
$lang_text['ll_empty_list'] = 'Keine Elemente verfgbar!';
$lang_text['ll_empty_search'] = 'Suche lieferte keine Ergebnisse.';
$lang_text['ll_first_page'] = 'Erste Seite';
$lang_text['ll_group_action'] = 'Gruppenaktion auswhlen';
$lang_text['ll_info'] = 'Information';
$lang_text['ll_last_page'] = 'Letzte Seite';
$lang_text['ll_next'] = 'Nchster';
$lang_text['ll_next_2'] = 'Weiter';
$lang_text['ll_nothing'] = 'Kein Element angegeben';
$lang_text['ll_off'] = 'Aus';
$lang_text['ll_ok'] = 'OK';
$lang_text['ll_on'] = 'Ein';
$lang_text['ll_pages'] = 'Seiten:';
$lang_text['ll_perpage'] = 'Eintrge pro Seite';
$lang_text['ll_prev'] = 'Vorheriger';
$lang_text['ll_process_off'] = 'Der Abschaltvorgang luft';
$lang_text['ll_process_on'] = 'Der Anschaltvorgang luft';
$lang_text['ll_refresh'] = 'Aktualisieren';
$lang_text['ll_save'] = 'Speichern';
$lang_text['ll_search'] = 'Suchen';
$lang_text['ll_show'] = 'Zeigen';
$lang_text['ll_show_all'] = 'Alle zeigen';
$lang_text['ll_state_creating'] = 'Erstellen';
$lang_text['ll_state_delete'] = 'gelscht';
$lang_text['ll_state_locked'] = 'gesperrt';
$lang_text['ll_state_new'] = 'neu';
$lang_text['ll_state_ok'] = 'ok';
$lang_text['ll_state_process'] = 'Wird durchgefhrt';
$lang_text['ll_state_removing'] = 'Entfernen';
$lang_text['ll_total'] = 'Eintrge $VAR[0] - $VAR[1] von $VAR[2]';
$lang_text['lost_admin_pwd'] = 'Das Administrator Passwort zurckzusetzen kann nur direkt auf dem Confixx Server gemacht werden. Bitte lesen Sie die Dokumentation oder wenden Sie sich an Ihren Support um herauszubekommen, wie Sie das Kennwort des Administrators zurcksetzen knnen.';
$lang_text['lost_pwd_forgot'] = 'Haben Sie Ihr Passwort vergessen?';
$lang_text['lost_pwd_forgot_text'] = 'Wenn Sie Ihr Passwort vergessen haben, wird Confixx versuchen Ihnen zu helfen, indem es Ihnen ein neues Passwort per Email zuschickt.';
$lang_text['lost_pwd_forgot_warning'] = '<p><b>Achtung!!!</b></p>
<p>Sich das Passwort per Email zusenden lassen ist unsicher!</p>
<p>Sie mssen eine gltige Email Adresse in Confixx eingetragen haben, damit das Passwort erfolgreich verschickt werden kann!</p>
<p>Geben Sie Ihren Login und die eingetragene Email Adresse ein, um ein neues Passwort zu erhalten.</p>';
$lang_text['lost_pwd_ftppopuser'] = 'Sie versuchen das Passwort fr WebFTP oder WebMail zurckzusetzen. Bitte wenden Sie sich an den Benutzer, der diesen Account erstellt hat, damit dieser das Passwort zurcksetzt.';
$lang_text['lost_pwd_mail'] = 'Das neue Passwort fr den Benutzer $VAR[0] ist $VAR[1]';
$lang_text['lost_pwd_mail_subj'] = 'Passwort gendert';
$lang_text['lost_pwd_nomail'] = 'Erkennung schlug fehl! Ungltiger Login oder Email Adresse angegeben. Bitte Daten berprfen und erneut probieren.';
$lang_text['lost_pwd_nomail_reseller'] = 'Ungltige Email Adresse fr Login \'$VAR[0]\' angegeben. Bitte wenden Sie sich an Ihren Administrator, dass dieser Ihr Passwort zurcksetzt.';
$lang_text['lost_pwd_nomail_user'] = 'Ungltige Email Adresse fr Login \'$VAR[0]\' angegeben. Bitte wenden Sie sich an Ihren Anbieter oder Administrator, dass dieser Ihr Passwort zurcksetzt.';
$lang_text['lost_pwd_sent'] = 'Passwort wurde per E-Mail geschickt';
$lang_text['m_httpd_options'] = 'Httpd Optionen';
$lang_text['m_logout'] = 'Ausloggen';
$lang_text['me_httpd'] = 'Httpd Spezial';
$lang_text['measure__hours'] = '$VAR[0] Stunde(n)';
$lang_text['measure__minutes'] = '$VAR[0] Minute(n)';
$lang_text['messages__no_messages'] = 'Es sind keine Meldungen vorhanden!';
$lang_text['pi_address'] = 'Adresse';
$lang_text['pi_apply'] = 'Daten bernehmen';
$lang_text['pi_city'] = 'Stadt';
$lang_text['pi_company'] = 'Firma';
$lang_text['pi_country'] = 'Land';
$lang_text['pi_customerid'] = 'Kunden-ID';
$lang_text['pi_datasaved'] = 'Daten wurden gespeichert.';
$lang_text['pi_definable'] = 'Definierbare Felder';
$lang_text['pi_email'] = 'E-Mail-Adresse';
$lang_text['pi_fax'] = 'Fax';
$lang_text['pi_female'] = 'Weiblich';
$lang_text['pi_firstname'] = 'Vorname';
$lang_text['pi_gender'] = 'Geschlecht';
$lang_text['pi_input'] = 'Eingabe';
$lang_text['pi_label'] = 'Name';
$lang_text['pi_lastname'] = 'Nachname';
$lang_text['pi_male'] = 'Mnnlich';
$lang_text['pi_phone'] = 'Telefon';
$lang_text['pi_zip'] = 'Postleitzahl';
$lang_text['reg_menu_help'] = 'Hilfe';
$lang_text['server_anlegen_fehler_dbname'] = 'Ungltiger Datenbankname';
$lang_text['server_anlegen_fehler_noconnect'] = 'Verbindung zur Datenbank schlug fehl';
$lang_text['service_is_disabled'] = 'Sie haben keine Berechtigung, diese Leistung zu benutzen.';
$lang_text['session_expired'] = 'Die Sitzung ist abgelaufen';
$lang_text['sh_back_to_admin'] = 'Zurck zur Admin-Oberflche';
$lang_text['sh_domains'] = 'Domains';
$lang_text['sh_services'] = 'Dienste';
$lang_text['short_pass_error'] = 'Ihr Passwort muss aus mindestens 6 Zeichen bestehen. Maximal sind $VAR[0] Zeichen erlaubt. Bitte fllen Sie das Formular erneut aus.';
$lang_text['simple_mode'] = 'Einfacher Modus';
$lang_text['sqltype_bad_number'] = 'Zahlenformat Fehler in der safe_query Funktion';
$lang_text['sqltype_bad_parameter'] = 'Falsches Argument in der safe_query Funktion';
$lang_text['sqltype_wrong_arguments'] = 'Falsche Anzahl an Argumenten in der safe_query Funktion';
$lang_text['suid_no_tar'] = 'Tar-Archive werden auf dem Server nicht untersttzt';
$lang_text['suid_no_unzip'] = 'Zip-Archive werden auf dem Server nicht untersttzt';
$lang_text['uc_awstats'] = 'AWstats / Statistiken';
$lang_text['uc_backup'] = 'Backup';
$lang_text['uc_backup_upload'] = 'Backup & Upload';
$lang_text['uc_coldfusion'] = 'ColdFusion';
$lang_text['uc_cssl'] = 'SSL';
$lang_text['uc_dbext'] = 'Externer MySQL-Zugriff';
$lang_text['uc_dirlist'] = 'Verzeichnisliste';
$lang_text['uc_dnr'] = 'DNR';
$lang_text['uc_dns'] = 'DNS';
$lang_text['uc_drweb'] = 'DrWeb';
$lang_text['uc_extmysql'] = 'Externer MySQL-Zugriff';
$lang_text['uc_fehlerseiten'] = 'Fehlerdateien definieren';
$lang_text['uc_frontpage'] = 'FrontPage-Support';
$lang_text['uc_ftp'] = 'FTP';
$lang_text['uc_invalidchar'] = 'Ungltiges Zeichen im Feld <b>$VAR[0]</b>';
$lang_text['uc_limit'] = 'Wert im Feld <b>$VAR[0]</b> ist zu gro, Sie knnen maximal <b>$VAR[1]</b> Elemente zuweisen';
$lang_text['uc_mailquota'] = 'Mail-Quota';
$lang_text['uc_maxatdomains'] = 'At-Domains';
$lang_text['uc_maxautoresponder'] = 'Anzahl E-Mail-Autoresponder';
$lang_text['uc_maxcronjobs'] = 'Cronjobs';
$lang_text['uc_maxemail'] = 'Anzahl E-Mail-Adressen';
$lang_text['uc_maxftp'] = 'Anzahl zustzlicher FTP-Benutzer';
$lang_text['uc_maximum'] = 'max.';
$lang_text['uc_maximume'] = 'Wert im Feld <b>$VAR[0]</b> darf <b>$VAR[1]</b> nicht bersteigen';
$lang_text['uc_maxkb'] = 'Speicherplatz';
$lang_text['uc_maxmaillist'] = 'Mailinglisten';
$lang_text['uc_maxmysql'] = 'MySQL-Datenbanken';
$lang_text['uc_maxpop'] = 'Anzahl POP3-Maiboxen';
$lang_text['uc_maxsubdomains'] = 'Erstellbare Subdomains';
$lang_text['uc_maxtransfer'] = 'Enthaltener Traffic';
$lang_text['uc_maxwebapp'] = 'Webapplikationen';
$lang_text['uc_modpython'] = 'Modul mod_python';
$lang_text['uc_perl'] = 'CGI/Perl';
$lang_text['uc_php'] = 'PHP';
$lang_text['uc_phpupload'] = 'PHP-Upload';
$lang_text['uc_popmaxkb'] = 'Mail-Speicherplatz';
$lang_text['uc_pwschutz'] = 'Passwortgeschtzte Verzeichnisse';
$lang_text['uc_restore'] = 'Wiederherstellen';
$lang_text['uc_scponly'] = 'Scp/SFTP';
$lang_text['uc_shell'] = 'Shell';
$lang_text['uc_spamfilter'] = 'Spamfilter';
$lang_text['uc_ssi'] = 'SSI';
$lang_text['uc_statistik'] = 'Webalizer / Statistiken';
$lang_text['uc_stdcgi'] = 'Standard CGI-Skripte';
$lang_text['uc_stdshell'] = 'Standard';
$lang_text['uc_wap'] = 'WAP';
$lang_text['uc_webftp'] = 'WebFTP';
$lang_text['uc_webmail'] = 'WebMail';
$lang_text['uc_webshop'] = 'WebShop';
$lang_text['uc_wildcard'] = 'Wildcard-Subdomains';
$lang_text['uplevel_label'] = 'Eine Ebene hher';
$lang_text['webshop_auto_fail_subject'] = 'Automatische Registrierung';
$lang_text['webshop_auto_ok_subject'] = 'Automatische Registrierung';
$lang_text['webshop_domains_limit'] = 'Ausgewhlter Plan erlaubt nur bis zu $VAR[0] Domains';
$lang_text['webshop_domains_wrong_domain'] = 'Inkorrekter Domainname: $VAR[0]';
$lang_text['webshop_limit_maxatdomains'] = 'Bis zu $VAR[0] At-Domains';
$lang_text['webshop_limit_maxautoresponder'] = 'Bis zu $VAR[0] Autoresponder';
$lang_text['webshop_limit_maxcronjobs'] = 'Bis zu $VAR[0] Cronjobs';
$lang_text['webshop_limit_maxdomains'] = 'Bis zu $VAR[0] Domains';
$lang_text['webshop_limit_maxemail'] = 'Bis zu $VAR[0] E-Mail-Adressen';
$lang_text['webshop_limit_maxftp'] = 'Bis zu $VAR[0] FTP-Benutzer';
$lang_text['webshop_limit_maxkb'] = 'Bis zu $VAR[0] KB Speicherplatz';
$lang_text['webshop_limit_maxmaillist'] = 'Bis zu $VAR[0] Mailinglisten';
$lang_text['webshop_limit_maxmysql'] = 'Bis zu $VAR[0] MySQL-Datenbanken';
$lang_text['webshop_limit_maxpop'] = 'Bis zu $VAR[0] POP3-Mailboxen';
$lang_text['webshop_limit_maxsubdomains'] = 'Bis zu $VAR[0] Subdomains';
$lang_text['webshop_limit_maxtransfer'] = 'Bis zu $VAR[0] MB Traffic';
$lang_text['webshop_limit_wildcard'] = 'Bis zu $VAR[0] Wildcard-Subdomains';
$lang_text['webshop_name'] = 'Confixx-Webshop';
$lang_text['webshop_notification_subject'] = 'Sie haben eine neue Registrierungsanfrage';
$lang_text['webshop_personal_error'] = 'Einige bentigte Felder wurden falsch ausgefllt. Bitte versuchen Sie es erneut:';
$lang_text['webshop_service_coldfusion'] = 'ColdFusion';
$lang_text['webshop_service_dirlist'] = 'Verzeichnisliste';
$lang_text['webshop_service_fehlerseiten'] = 'Definierbare Fehlerdateien';
$lang_text['webshop_service_ftp'] = 'FTP';
$lang_text['webshop_service_perl'] = 'Perl/CGI';
$lang_text['webshop_service_php'] = 'PHP';
$lang_text['webshop_service_phpupload'] = 'PHP-Upload';
$lang_text['webshop_service_pwschutz'] = 'Passwortgeschtzte Verzeichnisse';
$lang_text['webshop_service_scponly'] = 'Scp/SFTP';
$lang_text['webshop_service_shell'] = 'Shellzugriff';
$lang_text['webshop_service_spamfilter'] = 'Spamfilter';
$lang_text['webshop_service_ssi'] = 'SSI';
$lang_text['webshop_service_wap'] = 'WAP';
$lang_text['webshop_service_webftp'] = 'WebFTP';
$lang_text['webshop_service_webmail'] = 'WebMail';
$lang_text['webshop_ulimit'] = 'unbegrenzt';
$lang_text['webshop_ulimit_maxatdomains'] = 'Unbegrenzte At-Domains';
$lang_text['webshop_ulimit_maxautoresponder'] = 'Unbegrenzte Autoresponder';
$lang_text['webshop_ulimit_maxcronjobs'] = 'Unbegrenzte Cronjobs';
$lang_text['webshop_ulimit_maxdomains'] = 'Unbegrenzte Domains';
$lang_text['webshop_ulimit_maxemail'] = 'Unbegrenzte E-Mail-Adressen';
$lang_text['webshop_ulimit_maxftp'] = 'Unbegrenzte FTP-Benutzer';
$lang_text['webshop_ulimit_maxkb'] = 'Unbegrenzter Speicherplatz';
$lang_text['webshop_ulimit_maxmaillist'] = 'Unbegrenzte Mailinglisten';
$lang_text['webshop_ulimit_maxmysql'] = 'Unbegrenzte MySQL-Datenbanken';
$lang_text['webshop_ulimit_maxpop'] = 'Unbegrenzte POP3-Mailboxen';
$lang_text['webshop_ulimit_maxsubdomains'] = 'Unbegrenzte Subdomains';
$lang_text['webshop_ulimit_maxtransfer'] = 'Unbegrenzter Traffic';
$lang_text['webshop_ulimit_wildcard'] = 'Unbegrenzte Wildcard-Subdomains';


$lang_months['1'] = 'Januar';
$lang_months['2'] = 'Februar';
$lang_months['3'] = 'Mrz';
$lang_months['4'] = 'April';
$lang_months['5'] = 'Mai';
$lang_months['6'] = 'Juni';
$lang_months['7'] = 'Juli';
$lang_months['8'] = 'August';
$lang_months['9'] = 'September';
$lang_months['10'] = 'Oktober';
$lang_months['11'] = 'November';
$lang_months['12'] = 'Dezember';

    
?>
